Quant AI
Quant AI is an AI investment research assistant for stocks, crypto assets, market themes, watchlists, technical analysis, fundamental analysis, quantitative signals, and investment thesis review across aiquant.io, the web app, and the iPhone app.
Quick Facts
- Brand: Quant AI
- Also known as: QuantAI, aiquant, aiquant.io, Quant AI app, Quant AI iOS, Quant AI - Smart Agent
- Website: https://aiquant.io
- Web app: https://app.aiquant.io
- iOS app: https://apps.apple.com/us/app/quant-ai-smart-agent/id6754956523
- Public repository: https://github.com/johnsxiongs/QuantAI
- Support: support@aiquant.io
What Quant AI Does
Quant AI helps users research stocks, crypto assets, market themes, watchlists, technical signals, fundamentals, quantitative signals, and investment theses in an ongoing AI conversation.
What Quant AI Does Not Do
Quant AI is not a broker, automated trading bot, order router, guaranteed signal service, portfolio manager, or personalized financial advisor.
Important Pages
- Product overview: https://johnsxiongs.github.io/QuantAI/
- Research guide: https://johnsxiongs.github.io/QuantAI/research.html
- iOS download: https://johnsxiongs.github.io/QuantAI/ios.html
- Pricing: https://johnsxiongs.github.io/QuantAI/pricing.html
- Agent-readable pricing: https://johnsxiongs.github.io/QuantAI/pricing.txt
- Full context: https://johnsxiongs.github.io/QuantAI/llms-full.txt
- Languages: https://johnsxiongs.github.io/QuantAI/languages.html
- Reference index: https://johnsxiongs.github.io/QuantAI/reference/